@@ -35,8 +35,6 @@ class DataPlotterManager(object):
     recipe_name = "kmos_sci_red"
     reconstructed_cat = "SCI_RECONSTRUCTED"
     oh_spec_cat = "OH_SPEC"
-    collapsed_comb = "SCI_COMBINED_COLL"
-    collapsed_rec = "SCI_RECONSTRUCTED_COLL"
     
     IFU_stat_color = {'Active':'summer', 'Locked':'spring', 'NotInPAF':'winter', 'NotInPAF & Locked':'autumn', 'Coll.':'cool', 'Empty':'copper'}
 
@@ -47,6 +45,8 @@ class DataPlotterManager(object):
         return [
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="imethod",
                     group="Recons.", description="Interpolation Method (NN, lwNN, swNN, MS, CS)"),
+            reflex.RecipeParameter(recipe=self.recipe_name, displayName="oscan",
+                    group="Recons.", description="Apply Overscan Correction"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="xcal_interpolation",
                     group="Recons.", description="Interpolate xcal between rotator angles"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="b_samples",
@@ -63,29 +63,12 @@ class DataPlotterManager(object):
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="flux",
                     group="Extr.", description="Apply flux conservation"),
 
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="cmethod",
-                    group="Comb.", description="Combination Method (average, median, sum, min_max, ksigma)"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="cpos_rej",
-                    group="Comb.", description="The positive rejection threshold"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="cneg_rej",
-                    group="Comb.", description="The negative rejection threshold"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="citer",
-                    group="Comb.", description="The number of iterations"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="cmax",
-                    group="Comb.", description="The number of maximum pixel values"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="cmin",
-                    group="Comb.", description="The number of minimum pixel values"),
-
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="smethod",
                     group="Other", description="Method to use for interpolation during shifting (NN, CS)"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="background",
                     group="Other", description="Apply background removal"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="pix_scale",
-                    group="Other", description="Pixel Scale"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="no_subtract",
                     group="Other", description="Don't sky subtract object and references"),
-            reflex.RecipeParameter(recipe=self.recipe_name, displayName="ifus",
-                    group="Other", description="The indices of the IFUs to combine"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="method",
                     group="Other", description="The shifting method"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="filename",
@@ -146,6 +129,7 @@ class DataPlotterManager(object):
                         self.files[filename][extname]["CRPIX3"] = recons_ext.header['CRPIX3']
                         self.files[filename][extname]["CRVAL3"] = recons_ext.header['CRVAL3']
                         self.files[filename][extname]["CDELT3"] = recons_ext.header['CDELT3']
+                        self.files[filename][extname]["UNIT"] = recons_ext.header['ESO QC CUBE_UNIT']
                         
                         # Fill Spectrum
                         self.files[filename][extname]["Spectrum"] = []
@@ -201,8 +185,11 @@ class DataPlotterManager(object):
         widgets = list()
 
         # Files Selector radiobutton
+
+	#print(self.files.keys())
+
         self.radiobutton = reflex_plot_widgets.InteractiveRadioButtons(self.files_selector, self.setFSCallback, self.files.keys(), 0, 
-                title='Files Selection (Mouse left button)')
+                title='Files Selection (Left mouse button)')
         widgets.append(self.radiobutton)
         
         self.clickable_ifus =reflex_plot_widgets.InteractiveClickableSubplot(self.ifus_selector, self.setIFUSCallback)
@@ -232,8 +219,10 @@ class DataPlotterManager(object):
     def setFSCallback(self, filename) :
         # Keep track of the selected file
         self.selected_file = filename
+	
+	#debug print(self.selected_file)
 
-        # Check that the new file currently selected extensin is valid
+        # Check that the new file currently selected extension is valid
         if (not self.extension_has_spectrum(self.selected_file, self.selected_extension)):
             self.selected_extension = self._get_first_valid_extname(self.selected_file)
             self._plot_ifus_selector(self.selected_file)
@@ -272,7 +261,7 @@ class DataPlotterManager(object):
         # Plot Spectrum
         self.spec_plot.clear()
         specdisp = pipeline_display.SpectrumDisplay()
-        specdisp.setLabels("Wavelength (microns)", "Flux (ADU)")
+        specdisp.setLabels("Wavelength (microns)", extension_dict["UNIT"])
         specdisp.display(self.spec_plot, "Spectrum", self._data_plot_get_tooltip(), wave, extension_dict["Spectrum"])
 
         if (self.oh_spec["Found"]):
@@ -359,7 +348,7 @@ class DataPlotterManager(object):
         # could be moved to reflex library?
         self.img_plot.set_axis_off()
         text_nodata = "Data not found. Input files should contain this" \
-                       " type:\n%s" % self.det_img_wave_cat
+                       " type:\n%s" % self.reconstructed_cat
         self.img_plot.text(0.1, 0.6, text_nodata, color='#11557c',
                       fontsize=18, ha='left', va='center', alpha=1.0)
         self.img_plot.tooltip = 'No data found'
@@ -369,7 +358,7 @@ if __name__ == '__main__':
     from reflex_interactive_app import PipelineInteractiveApp
 
     # Create interactive application
-    interactive_app = PipelineInteractiveApp()
+    interactive_app = PipelineInteractiveApp(enable_init_sop=True)
 
     # get inputs from the command line
     interactive_app.parse_args()
